
Palettes in pychromatic
=======================

.. image:: output_2_0.png



.. image:: output_2_1.png



.. image:: output_2_2.png



.. image:: output_2_3.png



.. image:: output_2_4.png



.. image:: output_2_5.png



.. image:: output_2_6.png



.. image:: output_2_7.png



.. image:: output_2_8.png



.. image:: output_2_9.png



.. image:: output_2_10.png



.. image:: output_2_11.png



.. image:: output_2_12.png



.. image:: output_2_13.png



.. image:: output_2_14.png



.. image:: output_2_15.png
